# Molecular Dynamics

!!! info
	We assume that you are familiar with the basics of molecular dynamics simulations and you are here to learn how to perform them with `FHI-vibes`.

## Recap

Molecular Dynamics (MD) simulations aim at exploring the dynamical properties of a system defined by the Hamiltonian $\mathcal H$

$$
\begin{align}
\mathcal{H}(\mathbf{R}, \mathbf{P})=\sum_{I} \frac{\mathbf{P}_{I}^{2}}{2 M_{I}}+\mathcal{V}(\mathbf{R})~,
\label{eq:H}
\end{align}
$$

where ${\bf R} = \{ {\bf R}_I \}$ denotes the atomic positions, ${\bf P} = \{ {\bf P}_I \}$ the atomic momenta, $M_I$ the atomic mass, and $\mathcal V ({\bf R})$ is a many-body potential, e.g., given by an empirical force-field, or an _ab initio_ energy functional. The dynamical evolution of the  system is described by the equations of motion,

$$
\begin{align}
M_{I} \ddot{\mathbf{R}}_{I}(t)=\mathbf{F}_{I}(t)=-\nabla_{I} \mathcal{V}(\mathbf{R}(t))~,
\label{eq:Newton}
\end{align}
$$

where the acceleration $\ddot{\mathbf{R}}_{I}(t)$ of an atom at time $t$ is given by the atomic force ${\bf F}_I (t)$, i.e., the inverse gradient of the many-body potential $\mathcal V ({\bf R})$.

Equation $\eqref{eq:Newton}$ is solved numerically from a given initial condition $\{{\bf R} (t_0), {\bf P} (t_0) \}$, for example with the [Velocity Verlet integrator](https://en.wikipedia.org/wiki/Verlet_integration#Velocity_Verlet).

The dynamical information encoded in the phase-space trajectory $\Gamma (t) = \{{\bf R} (t), {\bf P} (t) \}$ can then be used to evaluate expectation values of observables, which are typically functions of phase-space points:

$$
\begin{align}
	\langle O\rangle
	%&= \frac{1}{\mathcal{Z}}
	%\int \mathrm{d} \mathbf{R} \mathrm{d} \mathbf{P} ~
	%	\mathrm{e}^{-\beta \mathcal{H}(\mathbf{R}, {\bf P})}
	%	O(\mathbf{R}, {\bf P})
	%	\label{eq:O1} \\
	&=
	\lim_{T \rightarrow \infty} \frac{1}{T}
	\int_0^T {\rm d} t ~
	O(\mathbf{R} (t), {\bf P} (t))
	\label{eq:O2}~,
	\end{align}
$$

where Eq. $\eqref{eq:O2}$ holds for [ergodic systems](https://en.wikipedia.org/wiki/Ergodicity).

Compared to approximate treatments of the nuclear dynamics, e.g., the [harmonic approximation discussed earlier](2_phonopy_intro.md), MD has the advantage that it accounts for the full potential~$\mathcal{V}(\mathbf{R})$ and
thus also for _anharmonic effects_ (contributions not captured by a the harmonic approximation).

### Example: Pressure

For example, $O$ could be the instantaneous pressure given by

$$
\begin{align}
\def\d\{{\rm d}}
p({\bf R}, {\bf P})
	= - \left. \left( \frac{\d \mathcal H ({\bf R}, {\bf P})}{\d V} \right)\right|_T
	= \frac{1}{3V} \sum_I \frac{{\bf P}_I^2}{M_I}
	+ \frac{1}{V} \frac{\d \mathcal V ({\bf R})}{\d V}
	~,
	\label{eq:p}
\end{align}
$$

where $\d / \d V$ denotes a volume derivative. For evaluating the thermodynamic expectation value of Eq. $\eqref{eq:p}$, we first note that $p$ decouples into two contributions

$$
\begin{align}
	p({\bf R}, {\bf P}) = p_{\rm Kin} ({\bf P}) + p_{\rm Pot} ({\bf R})~
	\label{eq:p2}
\end{align}
$$

which can be evaluated independently of each other. We thus have

$$
\begin{align}
	\left\langle p \right\rangle
		= \left\langle p_{\rm Kin} \right\rangle
		+ \left\langle p_{\rm Pot} \right\rangle~,
	\label{eq:p3}
\end{align}
$$

where $p_{\rm Kin}$ denotes the kinetic ideal gas contribution, which yields the familiar [[HansenMcDonald]](references.md#HansenMcDonald)

$$
\left\langle p_{\rm Kin} \right\rangle = \frac{N k_{\rm B} T}{V}~,
$$

and $p_{\rm Pot}$ denotes the potential contribution which needs to be evaluated for the configurations ${\bf R}(t)$ generated by Eq. $\eqref{eq:Newton}$, so that

$$
\begin{align}
\left\langle p_{\rm Pot} \right\rangle
	= \lim_{N_{\rm t} \rightarrow \infty} \frac{1}{N_{\rm t}}
	\sum_n^{N_{\rm t}}
	\frac{1}{V} \frac{\d \mathcal V \left({\bf R} (t_n) \right)}{\d V}
\label{eq:<pPot>}
\end{align}
$$

is the expectation value of pressure in a simulation with discrete time steps $t_n$. Since consecutive time steps in an MD simulation are necessarily correlated, Eq. $\eqref{eq:<pPot>}$ can converge quite slowly with the number of time steps $N_{\rm t}$. We come back to this in the next tutorials.

## Canonical Ensemble: Thermostats
A simulation as described above models a [_microcanonical ensemble_](https://en.wikipedia.org/wiki/Microcanonical_ensemble), where particle number $N$, volume $V$, and energy $E$ are conserved.

In order to simulate a [_canonical ensemble_](https://en.wikipedia.org/wiki/Canonical_ensemble), where instead of the energy $E$ the temperature $T$ is the thermodynamic variable, one typically models the system including an interaction with a fictitious heat bath which allows to control the target temperature of the  system.

### Langevin thermostat
`FHI-vibes` uses a Langevin thermostat for canonical sampling. In Langevin dynamics, modified equations of motion are used with

$$
\begin{align}
	\dot{\bf P}_I(t)
		= {\bf F}_I
		- \gamma {\bf P}_I(t)
		+ \sqrt{2 M_I k_{\rm B} \gamma T} \eta(t)
	\label{eq:Langevin}~,
\end{align}
$$

where $\gamma$ is a friction parameter corresponding to an inverse relaxation time $\tau = 1/\gamma$, and $\eta (t)$ is a white-noise term obeying $\langle\eta(t) \eta(0)\rangle= \delta(t)$, cf. Eq. (1) in [[Vanden-Eijnden2006]](references.md#Vanden-Eijnden2006). Please note that the delta function has a unit of inverse time.
